Page 145 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 145

Home

    His power was acquired by the terror tactics of the ANC.
    One of the methods used by the ANC was known as
    "necklacing," whereby a victim was executed by first
    tying his hands and then placing an automobile or truck
    tire around his or her body, filling it with gasoline or
    diesel fuel, and setting it on fire. Most of the victims
    were not whites but blacks who refused to support the
    ANC. Winnie Mandela, the wife of Nelson Mandela
    stated, "With our boxes of matches and our necklaces,
    we shall liberate this country." Hundreds of blacks have
    died an agonizing death by this method.

    None of this deterred the United Nations, the U. S.
    Government, the World Council of Churches, the world
    news media, and many U. S. Congressmen and Senators
    from working for a new South African Government
    headed by the ANC. Under the CFR-dominated Carter
    administration, a U. S. boycott was launched against
    South Africa that helped set the stage for a Communist

    While the U. S. media was daily attacking South
    Africa, not a word was spoken about the millions of
    Africans who were dying because of Communist
    devastation in other nations throughout Africa. As
    hundreds of thousands of black Africans were fleeing
    from these Communist countries and pouring into South
    Africa to survive, the media attacks on South Africa

    It is a sad commentary indeed, that a once great
    nation has fallen so low, that Communist terrorists are

    140

    The Secret Side of History

    take over.

    continued.